"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.utils = exports.modules = exports.routes = exports.middlewares = exports.helpers = exports.database = exports.config = exports.App = exports.gitFile = exports.PackageJson = void 0;
const PackageJson = ({ appName }) => {
    return `{
    "name": "${appName}",
    "version": "1.0.0",
    "description": "",
    "main": "bin/www",
    "scripts": {
      "start": "node bin/www"
    },
    "keywords": [],
    "author": "",
    "license": "ISC",
    "devDependencies": {
      "bcrypt": "^5.1.1",
      "compression": "^1.7.4",
      "cors": "^2.8.5",
      "debug": "^4.3.4",
      "dotenv": "^16.3.1",
      "helmet": "^7.1.0",
      "jsonwebtoken": "^9.0.2",
      "morgan": "^1.10.0"
    },
    "dependencies": {
      "express": "^4.18.2",
      "joi": "^17.11.0",
      "mongoose": "^8.0.3",
      "pino": "^8.17.2",
      "pino-pretty": "^10.3.1"
    }
  }
  `;
};
exports.PackageJson = PackageJson;
exports.gitFile = {
    gitIgnore: `# Logs
  *.log
  
  # Enviornment variables
  .env
  
  # Dependency directories
  /node_modules
  
  # Optional npm cache directory
  .npm
  temp
  
  # Optional REPL history
  .node_repl_history
  *.sql
  .idea
  .vscode
  logs/*
  cache
  *.txt
  *.aof
  data`,
};
exports.App = {
    app: `const express = require("express");
  const cors = require("cors");
  const compression = require("compression");
  const morgan = require("morgan");
  const path = require("path");
  const helmet = require("helmet");
  
  // imports
  const { logger } = require("./src/utils");
  const indexRoutes = require("./src/routes");
  const { errorHandler, routeHandler } = require("./src/helpers");
  
  // dbConnection
  require("./src/database");
  
  // express servers
  const app = express();
  
  // mongoose connection
  
  app.use(express.json());
  app.use(express.urlencoded({ extended: true, parameterLimit: 1000000 }));
  app.use(compression());
  app.use(compression());
  
  app.use(
    cors({
      origin: "*",
      methods: "GET,HEAD,PUT,PATCH,POST,DELETE",
      credentials: true,
      optionsSuccessStatus: 204,
    })
  );
  
  app.use(helmet());
  app.use(
    morgan(
      "[:date[web]] :method :url :status :response-time ms - :res[content-length]"
    )
  );
  
  // Enabled CORS
  app.use((req, res, next) => {
    res.setHeader("Access-Control-Allow-Origin", "*");
    res.header("Access-Control-Allow-Methods", "GET,PUT,POST,PATCH,DELETE");
    res.header("Access-Control-Allow-Headers", "Content-Type, Authorization");
  
    // intercept OPTIONS method
    if (req.method === "OPTIONS") {
      res.send(200);
    } else {
      next();
    }
  });
  
  // Public Path
  const publicPath = path.join(__dirname, "src/public");
  app.use(express.static(publicPath));
  
  // api Routes
  app.use("/api/v1", indexRoutes);
  
  // errorHandler
  app.use(errorHandler);
  
  // routesHandler
  app.use(routeHandler);
  
  // handle exceptions
  process.on("uncaughtException", function () {
    logger.error(err);
  });
  
  // handle rejection
  process.on("unhandledRejection", function (err) {
    logger.error(err);
  });
  
  module.exports = app;
  `,
};
exports.config = {
    index: `const constants = require("./constants");
  const messages = require("./messages");
  const httpCodes = require("./httpCodes");
  
  module.exports = {
    CONSTANTS: constants,
    MESSAGES: messages, /// (statusCode) => messages[statusCode] || "Unknown Status Code",
    HTTP_CODES: httpCodes,
    JWT: {
      ACCESS_TOKEN_SECRET: process.env.ACCESS_TOKEN_SECRET || "secret_key",
      REFRESH_TOKEN_SECRET: process.env.REFRESH_TOKEN_SECRET || "secret_key",
      ACCESS_TOKEN_TIME: process.env.ACCESS_TOKEN_TIME || "1d",
      REFRESH_TOKEN_TIME: process.env.REFRESH_TOKEN_TIME || "7d",
    },
  };
  `,
    httpCodes: `module.exports = {
    OK: 200,
    CREATED: 201,
    ACCEPTED: 202,
    NO_CONTENT: 204,
    BAD_REQUEST: 400,
    UNAUTHORIZED: 401,
    FORBIDDEN: 403,
    NOT_FOUND: 404,
    PRECONDITION_FAILED: 412,
    UNPROCESSABLE_ENTITY: 422,
    FAILED_DEPENDENCY: 424,
    TOO_MANY_REQUESTS: 429,
    INTERNAL_SERVER_ERROR: 500,
    BAD_GATEWAY: 502,
    SERVICE_UNAVAILABLE: 503,
    UNSUPPORTED_MEDIA: 415,
  };
  `,
    messages: `module.exports = {
    LOGIN_SUCCESS: "Login successful",
    LOGIN_FAILED: "Login failed",
    WRONG_PASSWORD: "Incorrect password",
    CREATED: "Record created successfully",
    CREATE_FAILED: "Failed to create record",
    GET_RECORD_SUCCESS: "Retrieved records successfully",
    GET_SINGLE_RECORD: "Retrieved single record successfully",
    UPDATE_SUCCESS: "Record updated successfully",
    DELETE_SUCCESS: "Record deleted successfully",
    NOT_FOUND: "Resource not found",
    BAD_REQUEST: "Bad request",
    UNAUTHORIZED: "Unauthorized access",
    FORBIDDEN: "Access forbidden",
    PRECONDITION_FAILED: "Precondition failed",
    TOO_MANY_REQUESTS: "Too many requests",
    SERVICE_UNAVAILABLE: "Service unavailable",
    INTERNAL_SERVER_ERROR: "Internal server error",
  };
  `,
    constants: `module.exports = {
    APP: {
      port: process.env.PORT,
      env: process.env.NODE_ENV,
    },
    USER: {
      ROLES: {
        ADMIN: "ADMIN",
        USER: "USER",
      },
    },
  };
  `,
};
exports.database = {
    index: `require("dotenv").config();
  const mongoose = require("mongoose");
  const { logger } = require("../utils");
  
  const CONNECTION_STRING =
    process.env.CONNECTION_STRING || "mongodb://127.0.0.1:27017";
  const DB_NAME = process.env.DB_NAME || "packages";
  
  module.exports = (() => {
    mongoose
      .connect(CONNECTION_STRING, {
        dbName: DB_NAME,
      })
      .then(() => {
        logger.info("mongodb connected...");
      })
      .catch((err) => logger.error(err.message));
  
    mongoose.connection.on("connected", () => {
      logger.info("Mongoose connected to db...");
    });
  
    mongoose.connection.on("error", (err) => {
      logger.error(err.message);
    });
  
    mongoose.connection.on("disconnected", (err) => {
      logger.info("Mongoose connection is disconnected...");
    });
  
    process.on("SIGINT", () => {
      mongoose.connection.close();
    });
  })();
  `,
    models: {
        modelName: `const mongoose = require("mongoose");
    const bcrypt = require("bcrypt");
    const Schema = mongoose.Schema;
    
    const userSchema = new Schema(
      {
        role: { type: String, enum: ["USER", "ADMIN"], default: "USER" },
        name: { type: String },
        email: {
          type: String,
          unique: true,
          required: true,
        },
        password: { type: String },
        phone: { type: String },
        deletedAt: { type: Date, default: null },
      },
      { timestamps: true }
    );
    
    // hash password before saving to database
    userSchema.pre("save", async function (next) {
      try {
        const salt = await bcrypt.genSalt(10);
        const hashPassword = bcrypt.hash(this.password, salt);
        this.password = hashPassword;
        next();
      } catch (error) {
        next(error);
      }
    });
    
    // validate password
    userSchema.methods.isValidPassword = async function (password) {
      try {
        return bcrypt.compare(password, this.password);
      } catch (error) {
        throw error;
      }
    };
    
    const UserModel = mongoose.model("User", userSchema);
    module.exports = { UserModel };
    `,
    },
    seeders: {
        updateSeeder: `const { logger } = require("../../utils");
    exports.updateSeeds = () => logger.info("successfully Updated");
    `,
    },
};
exports.helpers = {
    index: `const errorHandler = require("./errorHandler");
  const responseHelper = require("./response");
  const routeHandler = require("./routeHandler");
  
  module.exports = { errorHandler, responseHelper, routeHandler };
  `,
    errorHandler: `const { HTTP_CODES } = require("../config");
  const { ErrorResponse } = require("./errorResponse");
  const { logger } = require("../utils");
  const { serviceResponse } = require("./response");
  
  // eslint-disable-next-line no-unused-vars
  const errorHandler = (err, req, res, next) => {
    let error = { ...err };
  
    error.message = err.message;
  
    if (err.code === HTTP_CODES.INTERNAL_SERVER_ERROR || (!err.code && !err.type))
      logger.error(err);
  
    if (err.type === "TypeError") {
      const message = "TypeError" + err.value;
      error = new ErrorResponse(message, HTTP_CODES.BAD_REQUEST);
    }
  
    if (err.name === "CastError") {
      const message = "Resource not found with ID of " + err.value;
      error = new ErrorResponse(message, HTTP_CODES.NOT_FOUND);
    }
  
    if (err.code === 11000) {
      const message = "Duplicate field value entered";
      error = new ErrorResponse(message, HTTP_CODES.BAD_REQUEST);
    }
  
    if (err.statusCode === 412) {
      const message = error.message.split("/");
      error = new ErrorResponse(
        message[0].split('"').join(""),
        HTTP_CODES.BAD_REQUEST
      );
    }
  
    res
      .status(error.statusCode || 500)
      .json(
        serviceResponse(
          false,
          error.statusCode || 500,
          error.message || "Something went wrong. Please try again later.",
          error.err || {}
        )
      );
  };
  
  module.exports = errorHandler;
  `,
    response: `const { HTTP_CODES } = require("../config");

  const formatResponse = (res, success, statusCode, message = "Success", data) =>
    res.status(statusCode).json({
      success,
      code: statusCode || 500,
      message,
      data,
    });
  
  exports.success = (res, message, data) =>
    formatResponse(res, true, HTTP_CODES.OK, message, data);
  exports.created = (res, message, data) =>
    formatResponse(res, true, HTTP_CODES.CREATED, message, data);
  exports.noContent = (res) => res.status(HTTP_CODES.NO_CONTENT).send();
  
  exports.serviceResponse = (success, code, message, data = {}) => {
    return { success, code, message, data };
  };
  
  // Success Response
  exports.successResponse = (res, code, message, data) =>
    formatResponse(res, true, code, message, data);
  
  // Error Response
  exports.errorResponse = (res, code, message, data) =>
    formatResponse(res, false, code, message, data);
  `,
    routeHandler: `const { HTTP_CODES } = require('../config');

  const routeHandler = async (req, res) => {
      res.status(HTTP_CODES.NOT_FOUND || 500).json({
          success: false,
          code: HTTP_CODES.NOT_FOUND || 500,
          message: 'Route Not Found',
          data: {},
      });
  };
  
  module.exports = routeHandler;
  `,
    errorResponse: {
        index: `const BadRequestException = require("./badRequest");
    const NotFoundException = require("./notFound");
    const PreconditionException = require("./precondition");
    const UnauthorizedException = require("./unauthorized");
    const UnHandledException = require("./unhandled");
    const ErrorResponse = require("./errorResponse");
    
    module.exports = {
      BadRequestException,
      NotFoundException,
      PreconditionException,
      UnauthorizedException,
      UnHandledException,
      ErrorResponse,
    };
    `,
        badRequest: `const { HTTP_CODES } = require("../../config");

    class BadRequestException extends Error {
      constructor(message, err = null) {
        super(message);
        this.type = "Bad Request";
        this.statusCode = HTTP_CODES.BAD_REQUEST;
        this.err = err;
      }
    }
    
    module.exports = BadRequestException;
    `,
        errorResponse: `class ErrorResponse extends Error {
      constructor(message, statusCode) {
          super(message);
          this.type = 'Error';
          this.statusCode = statusCode;
      }
  }
  
  module.exports = ErrorResponse;
  `,
        notFound: `const { HTTP_CODES } = require('../../config');

    class NotFoundException extends Error {
        constructor(message) {
            super(message);
            this.type = 'Not Found';
            this.statusCode = HTTP_CODES.NOT_FOUND;
        }
    }
    
    module.exports = NotFoundException;
    `,
        precondition: `const { HTTP_CODES } = require("../../config");

    class PreconditionException extends Error {
      constructor(message, err = null) {
        super(message);
        this.type = "Precondition Failed";
        this.statusCode = HTTP_CODES.PRECONDITION_FAILED;
        this.err = err;
      }
    }
    
    module.exports = PreconditionException;
    `,
        unauthorized: `const { HTTP_CODES } = require("../../config");

    class UnHandledException extends Error {
      constructor(err = null) {
        const message = "Internal Server Error";
        super(message);
        this.type = "Internal Server Error";
        this.err = err;
        this.statusCode = HTTP_CODES.INTERNAL_SERVER_ERROR;
      }
    }
    
    module.exports = UnHandledException;
    `,
        unhandled: `const { HTTP_CODES } = require("../../config");

    class UnHandledException extends Error {
      constructor(err = null) {
        const message = "Internal Server Error";
        super(message);
        this.type = "Internal Server Error";
        this.err = err;
        this.statusCode = HTTP_CODES.INTERNAL_SERVER_ERROR;
      }
    }
    
    module.exports = UnHandledException;
    `,
    },
};
exports.middlewares = {
    index: `const {
    isAuthenticated,
    validateAccessToken,
    validateRefreshToken,
  } = require("./authorization");
  const validation = require("./validation");
  
  module.exports = {
    isAuthenticated,
    validateAccessToken,
    validateRefreshToken,
    validationMiddleware: validation,
  };
  `,
    authorization: `const { UnauthorizedException } = require("../helpers/errorResponse");
  const { jwt } = require("../utils");
  
  module.exports = {
    validateAccessToken:
      (allowedRoles = []) =>
      async (req, res, next) => {
        try {
          if (!req.headers.authorization)
            throw new UnauthorizedException("Token header not found");
  
          const token = req.headers.authorization.split(" ")[1]; // Extracting Bearer token from header.
  
          if (!token) throw new UnauthorizedException("Token not found");
  
          const decoded = await jwt.verifyAccessToken(token);
  
          if (allowedRoles.includes(decoded.role)) {
            req.user = decoded;
            next();
          } else {
            throw new UnauthorizedException("Oops! Unauthorised access");
          }
        } catch (error) {
          next(error);
        }
      },
    validateRefreshToken:
      (allowedRoles = []) =>
      async (req, res, next) => {
        try {
          if (!req.headers.authorization)
            throw new UnauthorizedException("Token header not found");
  
          const token = req.headers.authorization.split(" ")[1]; // Extracting Bearer token from header.s
          if (!token) throw new UnauthorizedException("Token not found");
          const decoded = await jwt.verifyRefreshToken(token);
  
          if (allowedRoles.includes(decoded.role)) {
            req.user = decoded;
            next();
          } else {
            throw new UnauthorizedException("Oops! Unauthorised access");
          }
        } catch (error) {
          next(error);
        }
      },
  
    isAuthenticated: (req, res, next) => {
      if (req.user) {
        next();
      } else {
        throw new UnauthorizedException("Oops! Unauthorised access");
      }
  
      // if (!req.isAuthenticated()) {
      //   throw new UnauthorizedException("Oops! Unauthorised access");
      // }
      // next();
    },
  };
  `,
    validation: `const {
    UnHandledException,
    PreconditionException,
  } = require("../helpers/errorResponse");
  
  const options = {
    basic: {
      abortEarly: false,
      convert: true,
    },
    array: {
      abortEarly: false,
      convert: true,
    },
  };
  
  module.exports = (schema) => (req, res, next) => {
    Object.keys(schema).forEach((key) => {
      const { error } = schema[key].validate(req[key], options);
      console.log(error);
      if (error) {
        console.log(error);
        const message = error.details[0].message || "Invalid Inputs";
        throw new PreconditionException(message);
      }
    });
    next();
  };
  `,
};
exports.routes = {
    index: `const express = require("express");
  const { usersRoutes } = require("../modules/users");
  const router = express.Router();
  
  router.use("/users", usersRoutes);
  
  module.exports = router;
  `,
};
exports.modules = {
    users: {
        index: `const usersRoutes = require('./users.routes')
    const usersService = require('./users.service')
    
    module.exports = { usersRoutes, usersService }`,
        usersController: `const usersService = require("./users.service");
    const { responseHelper } = require("../../helpers");
    
    exports.createUsers = async (req, res, next) => {
      try {
        const { body } = req;
        const response = await usersService.createUsers(body);
        if (!response.success) {
          return responseHelper.errorResponse(
            res,
            response.code,
            response.message,
            response.data
          );
        }
        return responseHelper.successResponse(
          res,
          response.code,
          response.message,
          response.data
        );
      } catch (error) {
        next(error);
      }
    };
    
    exports.loginUsers = async (req, res, next) => {
      try {
        const { body } = req;
        const response = await usersService.loginUsers(body);
        if (!response.success) {
          return responseHelper.errorResponse(
            res,
            response.code,
            response.message,
            response.data
          );
        }
        return responseHelper.successResponse(
          res,
          response.code,
          response.message,
          response.data
        );
      } catch (error) {
        next(error);
      }
    };
    
    exports.getAllUsers = async (req, res, next) => {
      try {
        const response = await usersService.getAllUsers();
        if (!response.success) {
          return responseHelper.errorResponse(
            res,
            response.code,
            response.message,
            response.data
          );
        }
        return responseHelper.successResponse(
          res,
          response.code,
          response.message,
          response.data
        );
      } catch (error) {
        next(error);
      }
    };
    
    exports.getSingleUsers = async (req, res, next) => {
      try {
        const { params } = req;
        const response = await usersService.getSingleUsers(params);
        if (!response.success) {
          return responseHelper.errorResponse(
            res,
            response.code,
            response.message,
            response.data
          );
        }
        return responseHelper.successResponse(
          res,
          response.code,
          response.message,
          response.data
        );
      } catch (error) {
        next(error);
      }
    };
    
    exports.updateAllUsers = async (req, res, next) => {
      try {
        const { params, body } = req;
        const response = await usersService.updateAllUsers({
          id: params.id,
          payload: body,
        });
    
        if (!response.success) {
          return responseHelper.errorResponse(
            res,
            response.code,
            response.message,
            response.data
          );
        }
        return responseHelper.successResponse(
          res,
          response.code,
          response.message,
          response.data
        );
      } catch (error) {
        next(error);
      }
    };
    
    exports.deleteAllUsers = async (req, res, next) => {
      try {
        const { params } = req;
        const response = await usersService.deleteAllUsers({ id: params.id });
        if (!response.success) {
          return responseHelper.errorResponse(
            res,
            response.code,
            response.message,
            response.data
          );
        }
        return responseHelper.successResponse(
          res,
          response.code,
          response.message,
          response.data
        );
      } catch (error) {
        next(error);
      }
    };
    `,
        usersRoutes: `const express = require("express");
    const usersController = require("./users.controller");
    const {
      validationMiddleware,
      validateAccessToken,
    } = require("../../middlewares");
    const { usersSchema } = require("./users.validation");
    const { CONSTANTS } = require("../../config");
    
    const router = express.Router();
    
    router.post(
      "/",
      validationMiddleware(usersSchema.add),
      usersController.createUsers
    );
    router.post(
      "/login",
      validationMiddleware(usersSchema.login),
      usersController.loginUsers
    );
    router.get(
      "/",
      validateAccessToken(CONSTANTS.USER.ROLES.USER),
      usersController.getAllUsers
    );
    
    router.get(
      "/:id",
      validateAccessToken(CONSTANTS.USER.ROLES.USER),
      usersController.getSingleUsers
    );
    
    router.patch(
      "/:id",
      validateAccessToken(CONSTANTS.USER.ROLES.USER),
      validationMiddleware(usersSchema.update),
      usersController.updateAllUsers
    );
    
    router.delete(
      "/:id",
      validateAccessToken(CONSTANTS.USER.ROLES.USER),
      usersController.deleteAllUsers
    );
    
    module.exports = router;
    `,
        usersService: `const { HTTP_CODES, MESSAGES, CONSTANTS } = require("../../config");
    const { UserModel } = require("../../database/models/users.model");
    const { serviceResponse } = require("../../helpers/response");
    const { jwt } = require("../../utils");
    
    exports.createUsers = async (payload) => {
      const respose = await UserModel.create(payload);
      if (!respose) {
        return serviceResponse(false, HTTP_CODES.BAD_REQUEST, MESSAGES.BAD_REQUEST);
      }
      return serviceResponse(true, HTTP_CODES.CREATED, MESSAGES.CREATED, respose);
    };
    
    exports.loginUsers = async (payload) => {
      payload.email = payload.email.toLowerCase();
      const respose = await UserModel.findOne({
        email: payload.email,
        deletedAt: null,
      }).select("role email password");
    
      if (!respose) {
        return serviceResponse(false, HTTP_CODES.NOT_FOUND, MESSAGES.NOT_FOUND);
      }
    
      const isMatch = respose.isValidPassword(payload.password);
    
      if (!isMatch) {
        return serviceResponse(false, HTTP_CODES.BAD_REQUEST, MESSAGES.BAD_REQUEST);
      }
    
      const accessToken = jwt.generateAccessToken({
        id: respose._id,
        email: respose.email,
        role: CONSTANTS.USER.ROLES.USER,
      });
    
      const refreshToken = jwt.generateRefreshToken({
        id: respose._id,
        email: respose.email,
        role: CONSTANTS.USER.ROLES.USER,
      });
    
      return serviceResponse(true, HTTP_CODES.OK, MESSAGES.LOGIN_SUCCESS, {
        _id: respose._id,
        role: respose.role,
        email: respose.email,
        accessToken,
        refreshToken,
      });
    };
    
    exports.getAllUsers = async () => {
      const respose = await UserModel.find({ deletedAt: null });
      if (!respose) {
        return serviceResponse(
          false,
          HTTP_CODES.INTERNAL_SERVER_ERROR,
          MESSAGES.INTERNAL_SERVER_ERROR
        );
      }
      return serviceResponse(
        true,
        HTTP_CODES.OK,
        MESSAGES.GET_RECORD_SUCCESS,
        respose
      );
    };
    
    exports.getSingleUsers = async ({ id }) => {
      const respose = await UserModel.findOne({ _id: id, deletedAt: null });
      if (!respose) {
        return serviceResponse(false, HTTP_CODES.NOT_FOUND, MESSAGES.NOT_FOUND);
      }
      return serviceResponse(
        true,
        HTTP_CODES.OK,
        MESSAGES.GET_SINGLE_RECORD,
        respose
      );
    };
    
    exports.updateAllUsers = async ({ id, payload }) => {
      const respose = await UserModel.findOneAndUpdate(
        { _id: id, deletedAt: null },
        payload,
        { new: true }
      );
      if (!respose) {
        return serviceResponse(false, HTTP_CODES.NOT_FOUND, MESSAGES.NOT_FOUND);
      }
    
      return serviceResponse(true, HTTP_CODES.OK, MESSAGES.UPDATE_SUCCESS);
    };
    
    exports.deleteAllUsers = async ({ id }) => {
      const respose = await UserModel.findOneAndUpdate(
        { _id: id, deletedAt: null },
        { deletedAt: new Date() },
        { new: true }
      );
      if (!respose) {
        return serviceResponse(false, HTTP_CODES.NOT_FOUND, MESSAGES.NOT_FOUND);
      }
    
      return serviceResponse(true, HTTP_CODES.OK, MESSAGES.DELETE_SUCCESS);
    };
    `,
        usersValidation: `const Joi = require("joi");

    const usersSchema = {
      add: {
        body: Joi.object().keys({
          name: Joi.string().trim().required(),
          email: Joi.string().trim().email().trim().required(),
          password: Joi.string().trim().required(),
          phone: Joi.string().trim().required(),
        }),
      },
      update: {
        body: Joi.object().keys({
          name: Joi.string().trim(),
          phone: Joi.string().trim(),
        }),
      },
      login: {
        body: Joi.object().keys({
          email: Joi.string().trim().email().trim().required(),
          password: Joi.string().trim().required(),
        }),
      },
    };
    
    module.exports = { usersSchema };
    `,
    },
};
exports.utils = {
    index: `const logger = require("./logger");
  const jwt = require("./jwt");
  module.exports = { jwt, logger };
  `,
    jwt: `const { BadRequestException } = require("../helpers/errorResponse");
  const jwt = require("jsonwebtoken");
  const { JWT } = require("../config");
  
  exports.verifyAccessToken = (token) => {
    // eslint-disable-next-line no-unused-vars
    return new Promise((resolve, reject) => {
      jwt.verify(token, JWT.ACCESS_TOKEN_SECRET, (err, decoded) => {
        if (err) throw new BadRequestException("Invalid Token");
        resolve(decoded);
      });
    });
  };
  
  exports.verifyRefreshToken = (token) => {
    // eslint-disable-next-line no-unused-vars
    return new Promise((resolve, reject) => {
      jwt.verify(token, JWT.REFRESH_TOKEN_SECRET, (err, decoded) => {
        if (err) throw new BadRequestException("Invalid Token");
        resolve(decoded);
      });
    });
  };
  
  exports.generateAccessToken = (payload) => {
    return jwt.sign({ ...payload }, JWT.ACCESS_TOKEN_SECRET, {
      expiresIn: JWT.ACCESS_TOKEN_TIME,
    });
  };
  
  exports.generateRefreshToken = (payload) => {
    return jwt.sign({ ...payload }, JWT.REFRESH_TOKEN_SECRET, {
      expiresIn: JWT.REFRESH_TOKEN_TIME,
    });
  };
  `,
    logger: `const pino = require("pino");

  const logger = pino({
      transport: {
          target: "pino-pretty",
          options: {
              colorize: true,
              translateTime: "yyyy-dd-mm, h:MM:ss TT",
          }
      }
  })
  
  module.exports = logger`,
};
